EphemeralKey class

Inheritance

Constructors

EphemeralKey.fromJson(Map<String, dynamic> json)

Properties

created int
no setter
createdAt DateTime
no setter
customerId String
no setter
expires int
no setter
expiresAt DateTime
no setter
hashCode int
The hash code for this object.
no setterinherited
id String?
no setter
liveMode bool
no setter
object String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secret String?
no setter
type String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonString() String
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

FIELD_ASSOCIATED_OBJECTS → const String
FIELD_CREATED → const String
FIELD_EXPIRES → const String
FIELD_ID → const String
FIELD_LIVEMODE → const String
FIELD_OBJECT → const String
FIELD_SECRET → const String
FIELD_TYPE → const String
NULL → const String