Address class

Inheritance

Constructors

Address({String? city, String? country, String? line1, String? line2, String? postalCode, String? state})
Address.fromJson(Map<String, dynamic> json)

Properties

city String?
getter/setter pair
country String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
line1 String?
getter/setter pair
line2 String?
getter/setter pair
postalCode String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonString() String
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldCity → const String
fieldCountry → const String
fieldLine1 → const String
fieldLine2 → const String
fieldPostalCode → const String
fieldState → const String