CustomerSource class

Inheritance
Implemented types

Constructors

CustomerSource.fromJson(Map<String, dynamic> json)

Properties

hashCode int
The hash code for this object.
no setterinherited
id String?
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stripePaymentSource StripePaymentSource
getter/setter pair

Methods

asCard() StripeCard?
asSource() Source?
getSourceType() String?
getTokenizationMethod() String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonString() String
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited