Source class
- Inheritance
-
- Object
- StripeJsonModel
- Source
- Implemented types
Constructors
-
Source({String? id, int? amount, String? clientSecret, required SourceCodeVerification codeVerification, int? created, String? currency, String? flow, bool? liveMode, Map<
String, String> ? metaData, required SourceOwner owner, required SourceReceiver receiver, required SourceRedirect redirect, String? status, required Map<String, Object> sourceTypeData, StripeSourceTypeModel? sourceTypeModel, String? type, required String typeRaw, String? usage}) -
Source.fromJson(Map<
String, dynamic> json)
Properties
- amount ↔ int?
-
getter/setter pair
- clientSecret ↔ String?
-
getter/setter pair
- codeVerification ↔ SourceCodeVerification
-
getter/setter pair
- created ↔ int?
-
getter/setter pair
- currency ↔ String?
-
getter/setter pair
- flow ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
getter/setter pairoverride-getter
- liveMode ↔ bool?
-
getter/setter pair
-
metaData
↔ Map<
String, String> ? -
getter/setter pair
- owner ↔ SourceOwner
-
getter/setter pair
- receiver ↔ SourceReceiver
-
getter/setter pair
- redirect ↔ SourceRedirect
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sourceTypeData
↔ Map<
String, Object> -
getter/setter pair
- sourceTypeModel ↔ StripeSourceTypeModel?
-
getter/setter pair
- status ↔ String?
-
getter/setter pair
- type ↔ String?
-
getter/setter pair
- typeRaw ↔ String
-
getter/setter pair
- usage ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJsonString(
) → String -
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
MODELED_TYPES
→ Set<
String> -
final
Static Methods
-
asSourceFlow(
String? sourceFlow) → String? -
asSourceStatus(
String? sourceStatus) → String? -
asSourceType(
String sourceType) → String? -
asUsage(
String? usage) → String?
Constants
- ALIPAY → const String
- BANCONTACT → const String
- CANCELED → const String
- CARD → const String
- CHARGEABLE → const String
- CODE_VERIFICATION → const String
- CONSUMED → const String
- EPS → const String
- EURO → const String
- FAILED → const String
- FIELD_AMOUNT → const String
- FIELD_CLIENT_SECRET → const String
- FIELD_CODE_VERIFICATION → const String
- FIELD_CREATED → const String
- FIELD_CURRENCY → const String
- FIELD_FLOW → const String
- FIELD_ID → const String
- FIELD_LIVEMODE → const String
- FIELD_METADATA → const String
- FIELD_OBJECT → const String
- FIELD_OWNER → const String
- FIELD_RECEIVER → const String
- FIELD_REDIRECT → const String
- FIELD_STATUS → const String
- FIELD_TYPE → const String
- FIELD_USAGE → const String
- GIROPAY → const String
- IDEAL → const String
- MULTIBANCO → const String
- NONE → const String
- P24 → const String
- PENDING → const String
- RECEIVER → const String
- REDIRECT → const String
- REUSABLE → const String
- SEPA_DEBIT → const String
- SINGLE_USE → const String
- SOFORT → const String
- THREE_D_SECURE → const String
- UNKNOWN → const String
- USD → const String
- VALUE_SOURCE → const String