SourceCodeVerification class

Inheritance

Constructors

SourceCodeVerification(int? attemptsRemaining, String? status)
SourceCodeVerification.fromJson(Map<String, dynamic> json)

Properties

attemptsRemaining int?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonString() String
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

FAILED → const String
FIELD_ATTEMPTS_REMAINING → const String
FIELD_STATUS → const String
INVALID_ATTEMPTS_REMAINING → const int
PENDING → const String
SUCCEEDED → const String