SourceOwner class

Inheritance

Constructors

SourceOwner({Address? address, String? email, String? name, String? phone, Address? verifiedAddress, String? verifiedEmail, String? verifiedName, String? verifiedPhone})
SourceOwner.fromJson(Map<String, dynamic> json)

Properties

address Address?
getter/setter pair
email String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
getter/setter pair
phone String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verifiedAddress Address?
getter/setter pair
verifiedEmail String?
getter/setter pair
verifiedName String?
getter/setter pair
verifiedPhone String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonString() String
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited