SourceReceiver class
- Inheritance
-
- Object
- StripeJsonModel
- SourceReceiver
Constructors
- SourceReceiver({String? address, int? amountCharged, int? amountReceived, int? amountReturned})
-
SourceReceiver.fromJson(Map<
String, dynamic> json)
Properties
- address ↔ String?
-
getter/setter pair
- amountCharged ↔ int?
-
getter/setter pair
- amountReceived ↔ int?
-
getter/setter pair
- amountReturned ↔ int?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJsonString(
) → String -
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- FIELD_ADDRESS → const String
- FIELD_AMOUNT_CHARGED → const String
- FIELD_AMOUNT_RECEIVED → const String
- FIELD_AMOUNT_RETURNED → const String