SourceRedirect class

Inheritance

Constructors

SourceRedirect({String? returnUrl, String? status, String? url})
SourceRedirect.fromJson(Map<String, dynamic> json)

Properties

hashCode int
The hash code for this object.
no setterinherited
returnUrl String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
getter/setter pair
url String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonString() String
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

FAILED → const String
FIELD_RETURN_URL → const String
FIELD_STATUS → const String
FIELD_URL → const String
PENDING → const String
SUCCEEDED → const String