StripeJsonModel class abstract

Implementers

Constructors

StripeJsonModel()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonString() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

putStripeJsonModelListIfNotNull(Map<String, Object> upperLevelMap, String key, List<StripeJsonModel> jsonModelList) → void
putStripeJsonModelMapIfNotNull(Map<String, dynamic> upperLevelMap, String key, StripeJsonModel? jsonModel) → void