Token class

Implemented types

Properties

card StripeCard?
final
created DateTime
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
liveMode bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
final
used bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

asTokenType(String? possibleTokenType) String?
Converts an unchecked String value to a {@link TokenType} or {@code null}.
opj(Map<String, dynamic> json) Token?

Constants

FIELD_BANK_ACCOUNT → const String
FIELD_CARD → const String
FIELD_CREATED → const String
FIELD_ID → const String
FIELD_LIVEMODE → const String
FIELD_TYPE → const String
FIELD_USED → const String
TYPE_ACCOUNT → const String
TYPE_BANK_ACCOUNT → const String
TYPE_CARD → const String
TYPE_PII → const String