StripeApiHandler class

Constructors

StripeApiHandler()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addCustomerSource(String customerId, String sourceId, String secret) Future<Source>
createToken(Map<String, dynamic> params, String publishableKey) Future<Token?>
deleteCustomerSource(String customerId, String sourceId, String secret) Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
retrieveCustomer(String customerId, String secret) Future<Customer>
toString() String
A string representation of this object.
inherited
updateCustomerDefaultSource(String customerId, String sourceId, String secret) Future<Customer>
updateCustomerShippingInformation(String customerId, ShippingInformation shippingInfo, String secret) Future<Customer>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

CHARSET → const String
CUSTOMERS → const String
FIELD_ERROR → const String
FIELD_SOURCE → const String
HEADER_KEY_REQUEST_ID → const String
LIVE_API_BASE → const String
LIVE_API_PATH → const String
LIVE_LOGGING_BASE → const String
LOGGING_ENDPOINT → const String
MALFORMED_RESPONSE_MESSAGE → const String
SOURCES → const String
TOKENS → const String
VERSION_NAME → const String