StripeAPIError class
Constructors
-
StripeAPIError(String? requestId, Map<
String, dynamic> json) -
factory
Properties
- charge → String?
-
final
- code → String?
-
final
- declineCode → String?
-
final
- docUrl → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String?
-
final
- param → String?
-
final
- requestId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- FIELD_CHARGE → const String
- FIELD_CODE → const String
- FIELD_DECLINE_CODE → const String
- FIELD_DOC_URL → const String
- FIELD_MESSAGE → const String
- FIELD_PARAM → const String
- FIELD_TYPE → const String