stripe_text_utils library

Constants

HEX_ARRAY → const String
Util Array for converting bytes to a hex string. {@url http://stackoverflow.com/questions/9655181/convert-from-byte-array-to-hex-string-in-java}

Functions

hasAnyPrefix(String? number, List<String> prefixes) bool
Check to see if the input number has any of the given prefixes.
isBlank(String? value) bool
A checker for whether or not the input value is entirely whitespace. This is slightly more aggressive than the android TextUtils#isEmpty method, which only returns true for {@code null} or {@code ""}.
nullIfBlank(String value) String?
Swap {@code null} for blank text values.
removeSpacesAndHyphens(String? cardNumberWithSpaces) String?
Converts a card number that may have spaces between the numbers into one without any spaces. Note: method does not check that all characters are digits or spaces.