isBlank function

bool isBlank(
  1. String? value
)

A checker for whether or not the input value is entirely whitespace. This is slightly more aggressive than the android TextUtils#isEmpty method, which only returns true for {@code null} or {@code ""}.

@param value a possibly blank input string value @return {@code true} if and only if the value is all whitespace, {@code null}, or empty

Implementation

bool isBlank(String ? value) {
  return value == null || value.trim().isEmpty;
}