CustomerSession class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addCustomerSource(String sourceId) Future<Source>
deleteCustomerSource(String sourceId) Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
retrieveCurrentCustomer() Future<Customer>
toString() String
A string representation of this object.
inherited
updateCustomerDefaultSource(String sourceId) Future<Customer>
updateCustomerShippingInformation(ShippingInformation shippingInfo) Future<Customer>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance CustomerSession?
no setter

Static Methods

endCustomerSession() → void
initCustomerSession(EphemeralKeyProvider provider) → void

Constants

KEY_REFRESH_BUFFER_IN_SECONDS → const int