Stripe class

Properties

hashCode int
The hash code for this object.
no setterinherited
publishableKey String
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stripeAccount String
getter/setter pair

Methods

createBankAccountToken(StripeCard card) Future<Token?>?
createCardToken(StripeCard card) Future<Token?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance Stripe?
no setter

Static Methods

init(String publishableKey) → void