Customer class
- Inheritance
-
- Object
- StripeJsonModel
- Customer
Constructors
-
Customer.fromJson(Map<
String, dynamic> json)
Properties
- defaultSource ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasMore ↔ bool?
-
getter/setter pair
- id ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shippingInformation ↔ ShippingInformation?
-
getter/setter pair
-
sources
↔ List<
CustomerSource> -
getter/setter pair
- totalCount ↔ int?
-
getter/setter pair
- url ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJsonString(
) → String -
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- FIELD_DATA → const String
- FIELD_DEFAULT_SOURCE → const String
- FIELD_HAS_MORE → const String
- FIELD_ID → const String
- FIELD_OBJECT → const String
- FIELD_SHIPPING → const String
- FIELD_SOURCES → const String
- FIELD_TOTAL_COUNT → const String
- FIELD_URL → const String
- VALUE_APPLE_PAY → const String
- VALUE_CUSTOMER → const String
- VALUE_LIST → const String