ModelUtils class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
hasMonthPassed(
int? year, int? month, DateTime? now) → bool - Determines whether the input year-month pair has passed.
-
hasYearPassed(
int year, DateTime now) → bool - Determines whether or not the input year has already passed.
-
isWholePositiveNumber(
String value) → bool - Check to see whether the input string is a whole, positive number.
-
normalizeYear(
int year, DateTime now) → int