SourceCardData class
- Inheritance
-
- Object
- StripeJsonModel
- StripeSourceTypeModel
- SourceCardData
Constructors
Properties
-
additionalFields
↔ Map<
String, Object> -
getter/setter pairinherited
- addressLine1Check ↔ String?
-
getter/setter pair
- addressZipCheck ↔ String?
-
getter/setter pair
- brand ↔ String?
-
getter/setter pair
- country ↔ String?
-
getter/setter pair
- cvcCheck ↔ String?
-
getter/setter pair
- dynamicLast4 ↔ String?
-
getter/setter pair
- expiryMonth ↔ int?
-
getter/setter pair
- expiryYear ↔ int?
-
getter/setter pair
- funding ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- last4 ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
standardFields
↔ Set<
String> -
getter/setter pairinherited
- threeDSecureStatus ↔ String?
-
getter/setter pair
- tokenizationMethod ↔ String?
-
getter/setter pair
Methods
-
addStandardFields(
List< String> fields) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJsonString(
) → String -
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- FIELD_ADDRESS_LINE1_CHECK → const String
- FIELD_ADDRESS_ZIP_CHECK → const String
- FIELD_BRAND → const String
- FIELD_COUNTRY → const String
- FIELD_CVC_CHECK → const String
- FIELD_DYNAMIC_LAST4 → const String
- FIELD_EXP_MONTH → const String
- FIELD_EXP_YEAR → const String
- FIELD_FUNDING → const String
- FIELD_LAST4 → const String
- FIELD_THREE_D_SECURE → const String
- FIELD_TOKENIZATION_METHOD → const String
- NOT_SUPPORTED → const String
- OPTIONAL → const String
- REQUIRED → const String
- UNKNOWN → const String