SourceOwner class
- Inheritance
-
- Object
- StripeJsonModel
- SourceOwner
Constructors
Properties
- address ↔ Address?
-
getter/setter pair
- email ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String?
-
getter/setter pair
- phone ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- verifiedAddress ↔ Address?
-
getter/setter pair
- verifiedEmail ↔ String?
-
getter/setter pair
- verifiedName ↔ String?
-
getter/setter pair
- verifiedPhone ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJsonString(
) → String -
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- FIELD_ADDRESS → const String
- FIELD_EMAIL → const String
- FIELD_NAME → const String
- FIELD_PHONE → const String
- FIELD_VERIFIED_ADDRESS → const String
- FIELD_VERIFIED_EMAIL → const String
- FIELD_VERIFIED_NAME → const String
- FIELD_VERIFIED_PHONE → const String
- VERIFIED → const String