StripeApiHandler class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addCustomerSource(String customerId, String sourceId, String secret)
→ Future<Source>
-
-
createToken(Map<String, dynamic> params, String publishableKey)
→ Future<Token?>
-
-
deleteCustomerSource(String customerId, String sourceId, String secret)
→ Future<bool>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
retrieveCustomer(String customerId, String secret)
→ Future<Customer>
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
updateCustomerDefaultSource(String customerId, String sourceId, String secret)
→ Future<Customer>
-
-
updateCustomerShippingInformation(String customerId, ShippingInformation shippingInfo, String secret)
→ Future<Customer>
-